#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.52.1
visibility:           public
id:                   hledger-1.52.1-3pXQebWdUUSLWwqJ8MIOhm
key:                  hledger-1.52.1-3pXQebWdUUSLWwqJ8MIOhm
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  ad312077363e19e15e2bad3208513689
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anchor Hledger.Cli.Anon
    Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Aregister
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Run
    Hledger.Cli.Commands.Setup Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.52.1-3pXQebWdUUSLWwqJ8MIOhm
depends:
    Decimal-0.5.2-53XVb6O9fE66SQmvUAIDzC
    Diff-0.5-BjbdKLuZHF9G9mgcT2QyXB
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    ansi-terminal-1.1-BaaOJBYZHtd1MproObBlcZ base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 extra-1.7.16-1gq06OiTdkG7AFSCXWttYR
    filepath-1.4.300.1 githash-0.1.6.3-1km3YgvgTw5KVY8RjTrz4
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa haskeline-0.8.2.1
    hledger-lib-1.52.1-7O9MQE0QEC49ycuf9c6eXU
    http-client-0.7.19-ChmOISdzz1UJcIMHPfAR81
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    lucid-2.11.20250303-90P5FC1I18a9HigDcbdN9y
    math-functions-0.3.4.4-2jyjtsMXVm39iVUsjcD8pW
    megaparsec-9.7.0-HsgXVXUZbtJGVbAzhzLwYB
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    modern-uri-0.3.6.1-HgOAUnvXiWzYuU2NYccXM mtl-2.3.1 process-1.6.19.0
    regex-tdfa-1.3.2.5-8NW0m2HiVCwIy0zxjhdOWx
    req-3.13.4-9Dlp8Rm1rD86BCN0LC6mdD
    safe-0.3.21-GLTVOu0sarW6Z7N465j1G9
    shakespeare-2.1.7.1-IabZuHrxNmOG3MOVpkDAJn
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.2-9tyUPHiwq7fIOac17jBCXg
    temporary-1.3-2scYfc6PuLr90QcileTdw7 text-2.0.2
    text-ansi-0.3.0.1-7pYG1EijVTrHUJLP4bLfCm time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    utility-ht-0.0.17.2-CEB5QMW55oN7Z0hdj96MJH
    wizards-1.0.3-EMndOhiYuHdGTEqrX5mo0v

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

